@@ -4,7 +4,7 @@ import datetime
 
 from pyboleto.bank.itau import BoletoItau
 
-from testutils import BoletoTestCase
+from .testutils import BoletoTestCase
 
 
 class TestBancoItau(BoletoTestCase):
@@ -21,9 +21,6 @@ class TestBancoItau(BoletoTestCase):
         d.numero_documento = '456'
         self.dados = d
 
-    def test_render(self):
-        self.check_pdf_rendering('itau', self.dados)
-
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
             '34191.09008 00015.710296 30132.800001 9 43950000002980'
